@@ -370,7 +370,7 @@ globus_l_xio_test_server_request_callback(
         if (transfer_encoding != NULL)
         {
             response_headers[header_cnt].name = "Transfer-Encoding";
-            response_headers[header_cnt].name = transfer_encoding;
+            response_headers[header_cnt].value = transfer_encoding;
 
             header_cnt++;
         }
